
# Talentsoft Connector

> TalentSoft


🔗 https://www.cegid.com/fr/produits/cegid-talentsoft/

| Actions |
| ------- |
| [**Applicant new**](docs/applicant_new.md) |
| [**Applicant resume update**](docs/applicant_resume_update.md) |
| [**Applicant update**](docs/applicant_update.md) |
| [**Pull profiles**](docs/pull_profiles.md) |
| [**Pull jobs**](docs/pull_jobs.md) |
